from __future__ import with_statement # requires Python 2.5
import wx
from ui.ids import *

class MainMenuBar(wx.MenuBar):
    def __init__(self, *args, **kwds):
        # begin wxGlade: MainMenuBar.__init__
        wx.MenuBar.__init__(self, *args, **kwds)

        self.menuFile = wx.Menu()
        self.menuNewSpeechMap = wx.MenuItem(self.menuFile, ID_NEWSPEECHMAP, "New Speech Map", "Create a new speech map from existing text and sound resource.", wx.ITEM_NORMAL)
        self.menuFile.AppendItem(self.menuNewSpeechMap)
        self.menuFile.AppendSeparator()

        self.menuFileOpen = wx.Menu()
        self.menuOpenSpeechMap = wx.MenuItem(self.menuFile, ID_OPENSPEECHMAP, "Open Speech Map", "Open an existing speech map.", wx.ITEM_NORMAL)
        self.menuFileOpen.AppendItem(self.menuOpenSpeechMap)
        self.menuOpenText = wx.MenuItem(self.menuFile, ID_OPENTEXT, "Open Text", "Change the text file associated with the current speech map", wx.ITEM_NORMAL)
        self.menuFileOpen.AppendItem(self.menuOpenText)
        self.menuFile.AppendMenu(wx.NewId(), "Open", self.menuFileOpen)
        self.menuFile.AppendSeparator()

        self.menuFileSave = wx.Menu()
        self.menuSaveSpeechMap = wx.MenuItem(self.menuFile, ID_SAVESPEECHMAP, "Save Speech Map", "Save speech map, including comments for the text and sounds.", wx.ITEM_NORMAL)
        self.menuFileSave.AppendItem(self.menuSaveSpeechMap)
        self.menuSaveText = wx.MenuItem(self.menuFile, ID_SAVETEXT, "Save Text", "Save the text file (only needed if you have manually edit the dialogue).", wx.ITEM_NORMAL)
        self.menuFileSave.AppendItem(self.menuSaveText)
        self.menuFile.AppendMenu(wx.NewId(), "Save", self.menuFileSave)

        self.menuFileSaveAs = wx.Menu()
        self.menuSaveSpeechMapAs = wx.MenuItem(self.menuFile, ID_SAVESPEECHMAPAS, "Save Speech Map As...", "Save the speech map with a new name.", wx.ITEM_NORMAL)
        self.menuFileSaveAs.AppendItem(self.menuSaveSpeechMapAs)
        self.menuSaveTextAs = wx.MenuItem(self.menuFile, ID_SAVETEXTAS, "Save Text As...", "Save the text file with a new name.", wx.ITEM_NORMAL)
        self.menuFileSaveAs.AppendItem(self.menuSaveTextAs)
        self.menuFile.AppendMenu(wx.NewId(), "Save As...", self.menuFileSaveAs)
        self.menuFile.AppendSeparator()

        self.menuFileImport = wx.Menu()
        self.menuImportSounds = wx.MenuItem(self.menuFile, ID_IMPORTSOUNDS, "Import Sounds", "Batch import sounds, automatically assigning imported sounds to lines in the text file.")
        self.menuFileImport.AppendItem(self.menuImportSounds)
        self.menuFile.AppendMenu(wx.NewId(), "Import", self.menuFileImport)

        self.menuFileExport = wx.Menu()
        self.menuExportToGameResources = wx.MenuItem(self.menuFile, ID_EXPORTTOGAMERESOURCES, "Export to Game Resources", "Export to a sound resource and text file for use in the game.", wx.ITEM_NORMAL)
        self.menuFileExport.AppendItem(self.menuExportToGameResources)
        self.menuFileExport.AppendSeparator()
        self.menuExportSounds = wx.MenuItem(self.menuFile, ID_EXPORTSOUNDS, "Export Sounds", "Export all sounds & metadata, named by line number in the text.", wx.ITEM_NORMAL)
        self.menuFileExport.AppendItem(self.menuExportSounds)
        self.menuExportText = wx.MenuItem(self.menuFile, ID_EXPORTTEXT, "Export Text", "Export text whose descriptions match a certain criteria.", wx.ITEM_NORMAL)
        self.menuFileExport.AppendItem(self.menuExportText)
        self.menuExportTextScript = wx.MenuItem(self.menuFile, ID_EXPORTTEXTSCRIPT, "Export Text Script", "Export text between given lines, prefaced by descriptions (similar to a theatrical script).", wx.ITEM_NORMAL)
        self.menuFileExport.AppendItem(self.menuExportTextScript)
        self.menuFile.AppendMenu(wx.NewId(), "Export", self.menuFileExport)
        self.menuFile.AppendSeparator()

        self.menuFile.Append(wx.ID_EXIT, "Exit", "Quit, begone, depart, flee.", wx.ITEM_NORMAL)
        self.Append(self.menuFile, "File")

        # Edit menu
        self.menuEdit = wx.Menu()
        self.menuEditFind = wx.MenuItem(self.menuEdit, ID_EDITFIND, "Find...", "Search for text.", wx.ITEM_NORMAL)
        self.menuEdit.AppendItem(self.menuEditFind)
        self.menuEditGoto = wx.MenuItem(self.menuEdit, ID_EDITGOTO, "Go to line...", "Go to a specified line number in the text.", wx.ITEM_NORMAL)
        self.menuEdit.AppendItem(self.menuEditGoto)
        self.Append(self.menuEdit, 'Edit')

        # Tools menu
        self.menuTools = wx.Menu()
        self.menuExtractText = wx.MenuItem(self.menuTools, ID_EXTRACTTEXT, "Extract Text from Game", "Extract the text from a LucasArts game (using scummtr).", wx.ITEM_NORMAL)
        self.menuTools.AppendItem(self.menuExtractText)
        self.menuInsertText = wx.MenuItem(self.menuTools, ID_INSERTTEXT, "Insert Text into Game", "Insert the current open text file into a LucasArts game (using scummtr).", wx.ITEM_NORMAL)
        self.menuTools.AppendItem(self.menuInsertText)
        self.Append(self.menuTools, "Tools")

        # Help menu
        self.menuHelp = wx.Menu()
        self.menuHelpHelp = wx.MenuItem(self.menuHelp, wx.ID_HELP, "Help", "Open the help file.", wx.ITEM_NORMAL)
        self.menuHelp.AppendItem(self.menuHelpHelp)
        self.menuHelpAbout = wx.MenuItem(self.menuHelp, ID_ABOUT, "About", "Open the about dialog.", wx.ITEM_NORMAL)
        self.menuHelp.AppendItem(self.menuHelpAbout)
        self.Append(self.menuHelp, "Help")

        self.__set_properties()
        self.__do_layout()
        # end wxGlade

    def __set_properties(self):
        # begin wxGlade: MainMenuBar.__set_properties
        pass
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: MainMenuBar.__do_layout
        pass
        # end wxGlade

# end of class MainMenuBar
